.. _about:

About the Code
========================

I have developed HostPhot during my postdoc at ICE, Barcelona. The main purpose of this code is to do local and global photometry for the host galaxy of SNe Ia, although it can be used in other cases.
